pub type FixedSingletonEntry<T> = OptionEntry<T, T>;Expand description
A singleton entry whose value is a fixed generic type T.
Aliased Type
pub struct FixedSingletonEntry<T> { /* private fields */ }pub type FixedSingletonEntry<T> = OptionEntry<T, T>;A singleton entry whose value is a fixed generic type T.
pub struct FixedSingletonEntry<T> { /* private fields */ }